:Authors: - Josh Bailey

Faucet on ZodiacGX
==================

Introduction
------------

`ZodiacGX <https://northboundnetworks.com/products/zodiac-gx>`_ is a small
5 port multi table OF1.3 switch from
`Northbound Networks <https://northboundnetworks.com/>`_. Please see
the `documentation <https://support.northboundnetworks.com/support/solutions/articles/35000087210-openflow-controller-settings>`_
for configuring OpenFlow on the switch, and use ZodiacGX as the FAUCET
hardware type.


Caveats
-------

- The default OF port is 6633; it is recommended to use 6653.
- Minium firmware required is v1.01
